@@ -336,9 +336,11 @@ class ConnectWiseAPIClient(object):
                 try:
                     return response.json()
                 except JSONDecodeError as e:
-                    logger.error('An error occurred while decoding '
-                                 'the request: {}'.format(e))
-                    return {}
+                    logger.error(
+                        'Request failed during decoding JSON: GET {}: {}'
+                        .format(endpoint, e)
+                    )
+                    raise ConnectWiseAPIError('JSONDecodeError: {}'.format(e))
 
             elif response.status_code == 404:
                 msg = 'Resource not found: {}'.format(response.url)
